@@ -23,7 +23,7 @@ use strict;
 use warnings;
 use autodie;
 
-use List::MoreUtils qw(none);
+use List::MoreUtils qw(none any);
 
 use Lintian::Tags qw(tag);
 use Lintian::Check qw(check_maintainer);
@@ -32,8 +32,6 @@ use Lintian::Util qw(get_file_checksum);
 
 my $KNOWN_DISTS = Lintian::Data->new('changes-file/known-dists');
 my $SIGNING_KEY_FILENAMES = Lintian::Data->new('common/signing-key-filenames');
-my $DERIVATIVE_VERSIONS= Lintian::Data->new('changes-file/derivative-versions',
-    qr/\s*~~\s*/, sub { $_[1]; });
 
 sub run {
     my (undef, undef, $info, undef, $group) = @_;
@@ -83,7 +81,7 @@ sub run {
                                 ||($distribution eq 'wheezy-backports-sloppy'
                                     && $distnumber ne '7')
                                 ||($dist eq 'jessie' && $distnumber ne '8')
-                              ) {
+                            ) {
                                 tag
 'backports-upload-has-incorrect-version-number',
                                   $info->field('version'),
@@ -109,7 +107,7 @@ sub run {
                       # parse code here
                                 if ($change_line
                                     =~ m/^\s*(?:\w[-+0-9a-z.]*) \((?:[^\(\) \t]+)\)(?:(?:\s+[-+0-9a-z.]+)+)\;\s*(?:.*)$/i
-                                  ) {
+                                ) {
                                     $changes_versions++;
                                 }
                             }
@@ -122,6 +120,11 @@ sub run {
                             }
                         }
                     }
+                } else {
+                    tag
+                      'upload-has-backports-version-number',
+                      $info->field('version'), $distribution
+                      if $info->field('version') =~ m/~bpo(\d+)\+(\d+)$/;
                 }
                 if (!$KNOWN_DISTS->known($dist)) {
                     # bad distribution entry
@@ -136,7 +139,7 @@ sub run {
 
                     if ($changes
                         =~ m/^\s*(?:\w[-+0-9a-z.]*)\s*\([^\(\) \t]+\)\s*([-+0-9A-Za-z.]+)\s*;/
-                      ) {
+                    ) {
                         my $changesdist = $1;
                         if ($changesdist eq 'UNRELEASED') {
                             tag 'unreleased-changes';
@@ -247,6 +250,12 @@ sub run {
         }
     }
 
+    if (    any { $files->{$_}->{section} =~ m,^non-free/.+, } keys %$files
+        and $info->field('autobuild', '') ne 'yes'
+        and $info->field('architecture', '') eq 'source') {
+        tag 'source-only-upload-to-non-free-without-autobuild';
+    }
+
     # Check that we have a consistent number of checksums and files
     foreach my $alg (keys %num_checksums) {
         my $seen = $num_checksums{$alg};
@@ -256,14 +265,6 @@ sub run {
           if $seen != $expected;
     }
 
-    # Check version field
-    my $version = $info->field('version');
-    foreach my $re ($DERIVATIVE_VERSIONS->all) {
-        next if $version =~ m/$re/;
-        my $explanation = $DERIVATIVE_VERSIONS->value($re);
-        tag 'invalid-version-number-for-derivative', $version,"($explanation)";
-    }
-
     return;
 }
 
