@@ -47,7 +47,7 @@ my $KNOWN_DBG_PACKAGE = Lintian::Data->new(
     });
 
 sub run {
-    my ($pkg, undef, $info) = @_;
+    my ($pkg, undef, $info, undef, $group) = @_;
     my $debian_dir = $info->index_resolved_path('debian/');
     my $dcontrol;
     $dcontrol = $debian_dir->child('control') if $debian_dir;
@@ -77,7 +77,7 @@ sub run {
             m{\A \# \s* Vcs-(?:Git|Browser): \s*
                   (?:git|http)://git\.debian\.org/
                   (?:\?p=)?collab-maint/<pkg>\.git}osmx
-          ) {
+        ) {
             # Emit it only once per package
             tag 'control-file-contains-dh_make-vcs-comment'
               unless $seen_vcs_comment++;
@@ -92,11 +92,11 @@ sub run {
             if ($field =~ /^xs-vcs-/) {
                 my $base = $field;
                 $base =~ s/^xs-//;
-                tag 'xs-vcs-header-in-debian-control', $field
+                tag 'xs-vcs-field-in-debian-control', $field
                   if $src_fields->known($base);
             }
             if ($field eq 'xs-testsuite') {
-                tag 'xs-testsuite-header-in-debian-control', $field;
+                tag 'xs-testsuite-field-in-debian-control', $field;
             }
             if ($field eq 'xc-package-type') {
                 tag 'xc-package-type-in-debian-control', "line $.";
@@ -108,6 +108,11 @@ sub run {
             if (/^\Q$field\E: \s* \Q$field\E \s* :/xsmi) {
                 tag 'debian-control-repeats-field-name-in-value', "line $.";
             }
+            if (    $field =~ /^Rules?-Requires?-Roots?$/i
+                and $field ne 'rules-requires-root') {
+                tag 'spelling-error-in-rules-requires-root', $field,
+                  "(line $.)";
+            }
         }
     }
     close($fd);
@@ -184,7 +189,7 @@ sub run {
     for my $field (
         qw(build-depends build-depends-indep
         build-conflicts build-conflicts-indep)
-      ) {
+    ) {
         my $raw = $info->source_field($field);
         my $rel;
         next unless $raw;
@@ -196,7 +201,7 @@ sub run {
         for my $field (
             qw(pre-depends depends recommends suggests breaks
             conflicts provides replaces enhances)
-          ) {
+        ) {
             my $raw = $info->binary_field($bin, $field);
             my $rel;
             next unless $raw;
@@ -352,7 +357,7 @@ sub run {
                      )*                # zero or more additional lists
                      \s*$              # trailing spaces at the end
               }x
-          ) {
+        ) {
             tag 'invalid-restriction-formula-in-build-profiles-field', $raw,
               $bin;
         } else {
@@ -381,6 +386,20 @@ sub run {
         tag 'rules-requires-root-implicitly';
     }
 
+    if ($info->source_field('rules-requires-root', 'no') eq 'no') {
+      BINARY:
+        foreach my $proc ($group->get_binary_processables) {
+            my $pkg = $proc->pkg_name;
+            foreach my $file ($proc->info->sorted_index) {
+                my $owner = $file->owner . ':' . $file->group;
+                next if $owner eq 'root:root';
+                tag 'should-specify-rules-requires-root', $pkg, $file,
+                  "($owner)";
+                last BINARY;
+            }
+        }
+    }
+
     # find binary packages that Pre-Depend on multiarch-support without going
     # via ${misc:Pre-Depends}
     if ($info->source_field('build-depends')) {
@@ -413,6 +432,26 @@ sub run {
           unless $relation->implies('${gir:Depends}');
     }
 
+    if ($info->relation('build-depends')->implies('golang-go | golang-any')) {
+        # Verify that golang binary packages set Built-Using (except for
+        # arch:all library packages).
+        foreach my $bin (@package_names) {
+            my $bu = $info->binary_field($bin, 'built-using');
+            my $arch = $info->binary_field($bin, 'architecture');
+            if ($arch eq 'all') {
+                tag 'built-using-field-on-arch-all-package', $bin
+                  if defined($bu);
+            } else {
+                if (!defined($bu) || $bu !~ /\$\{misc:Built-Using\}/) {
+                    tag 'missing-built-using-field-for-golang-package', $bin;
+                }
+            }
+        }
+
+        tag 'missing-xs-go-import-path-for-golang-package'
+          unless $info->source_field('xs-go-import-path', '');
+    }
+
     return;
 }
 
@@ -484,7 +523,7 @@ sub check_dev_depends {
                 && $versions[1] =~ m/^\s*>[=>]\s* \$\{
                         (?: (?:binary|source):(?:Upstream-)?Version
                         |Source-Version)\}/xsm
-              ) {
+            ) {
                 tag 'weak-library-dev-dependency',
                   "$package on $depends[0], $depends[1]";
             }
@@ -515,7 +554,7 @@ sub check_relation {
                 (?:\w[^\s,|\$\(]+|\$\{\S+:Depends\})\s*
                 (?:\([^\)]*\)\s*)?
                    )/x
-      ) {
+    ) {
         my ($prev, $next) = ($1, $2);
         for ($prev, $next) {
             rstrip;
